# NIA
Nature Inspired Optimization Algorithms
Supported Algorithms :  
- [x] Genetic algorithm 
- [ ] Differential Evolution  
- [ ] Evolutionary Programming  
- [ ] Artificial Immune System  
- [ ] Clonal Selection Algorithm  
- [ ] Biogeography-based  
- [ ] Symbiotic Organisms Search  
- [ ] Ant Colony Optimization  
- [ ] Artificial Bee Colony  
- [ ] Moth Flame Optimization Algorithm  
- [ ] Cuckoo Search  
- [ ] Green Herons Optimization Algorithm  
- [ ] Bat Algorithm  
- [ ] Whale Optimization Algorithm  
- [ ] Krill Herd  
- [ ] Fish-swarm Algorithm  
- [ ] Grey Wolf Optimizer  
- [ ] Shuffle frog-leaping Algorithm  
- [ ] Cat Swarm Optimization  
- [ ] Flower Pollination Algorithm  
- [ ] Invasive Weed Optimization  
- [ ] Water Cycle Algorithm  
- [ ] Teaching–Learning-Based Optimization  
- [x] Particle Swarm Optimization  
- [ ] Simulated Annealing Algorithm  
- [ ] Gravitational Search Algorithm  
- [ ] Big Bang - Big Crunch  
